In this section you will find a number of useful guides which will help you
to understand [the overall development process](./overview_of_the_development_process.md)
of an agent service with the {{open_autonomy}} framework, including:

- creating the components of an agent that implement the service business logic (the {{fsm_app}}),
- creating the agents that make up the service,
- publishing the service in a remote or local repository,
- registering the service in the on-chain protocol, and
- deploying the service.

If you are new to the framework, we suggest that you start with the [set up](./set_up.md) and [quick start](./quick_start.md)
guides, and proceed with the remaining ones in the order presented.

In order not to lose the high-level view of the overall process, we present some of the guides at a high level of abstraction, and we redirect you to the appropriate sections to complete individual steps.
